summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJack Jansen <jack.jansen@cwi.nl>2002-09-06 20:23:09 (GMT)
committerJack Jansen <jack.jansen@cwi.nl>2002-09-06 20:23:09 (GMT)
commit3337ea731bab24110e82e6b9c59f85c8c7b3baa8 (patch)
treec7d546add7491e4a012e81498ab3788b47f2d173
parenta6db44f16918fdedd5eb153c56e622ca136881d4 (diff)
downloadcpython-3337ea731bab24110e82e6b9c59f85c8c7b3baa8.zip
cpython-3337ea731bab24110e82e6b9c59f85c8c7b3baa8.tar.gz
cpython-3337ea731bab24110e82e6b9c59f85c8c7b3baa8.tar.bz2
Remove .pyo files too.
-rw-r--r--Mac/scripts/zappycfiles.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Mac/scripts/zappycfiles.py b/Mac/scripts/zappycfiles.py
index 22a021c..dcd4133 100644
--- a/Mac/scripts/zappycfiles.py
+++ b/Mac/scripts/zappycfiles.py
@@ -1,5 +1,5 @@
#!/usr/local/bin/python
"""Recursively zap all .pyc files"""
import os
import sys
@@ -27,7 +27,7 @@ def zappyc(dir):
def walker(dummy, top, names):
for name in names:
- if name[-4:] == '.pyc':
+ if name[-4:] in ('.pyc', '.pyo'):
path = os.path.join(top, name)
print 'Zapping', path
if doit:
@@ -1,5 +1,5 @@
#!/usr/local/bin/python
-"""Recursively zap all .pyc files"""
+"""Recursively zap all .pyc and .pyo files"""
import os
import sys